from plone.app.customerize.testing import (  # noqa
    PLONE_APP_CUSTOMERIZE_FUNCTIONAL_TESTING,
)
from plone.testing import layered
from unittest import TestSuite

import doctest


def test_suite():
    suite = TestSuite()
    OPTIONFLAGS = doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE
    for testfile in ("testBrowserLayers.txt", "testCustomizeView.txt"):
        suite.addTest(
            layered(
                doctest.DocFileSuite(
                    testfile,
                    optionflags=OPTIONFLAGS,
                    package="plone.app.customerize.tests",
                ),
                layer=PLONE_APP_CUSTOMERIZE_FUNCTIONAL_TESTING,
            )
        )
    return suite



from AccessControl import ClassSecurityInfo
from AccessControl.class_init import InitializeClass
from five.customerize.interfaces import IViewTemplateContainer
from OFS.Folder import Folder
from Products.CMFCore.permissions import ManagePortal
from zope.interface import implementer


@implementer(IViewTemplateContainer)
class ViewTemplateContainer(Folder):
    """a local utility storing all ttw view templates provided
    by five.customerize in a folder"""

    id = "portal_view_customizations"
    title = "Manages view customizations"
    meta_type = "Plone View Customizations"

    security = ClassSecurityInfo()

    manage_options = (
        (dict(label="Registrations", action="registrations.html"),)
        + Folder.manage_options[0:1]
        + Folder.manage_options[2:]
    )

    @security.protected(ManagePortal)
    def addTemplate(self, id, template):
        """add the given ttw view template to the container"""
        self._setObject(id, template)
        return getattr(self, id)


InitializeClass(ViewTemplateContainer)



from plone.app.layout.viewlets.common import ViewletBase
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile


class StandardViewlet(ViewletBase):
    """a viewlet class for testing purposes"""

    render = ViewPageTemplateFile("standard.pt")


class LayerViewlet(ViewletBase):
    """a viewlet class for testing purposes"""

    render = ViewPageTemplateFile("local.pt")



from plone.app.testing import FunctionalTesting
from plone.app.testing import PloneFixture
from zope.configuration import xmlconfig


class PloneAppCustomerize(PloneFixture):
    def setUpZCML(self):
        super().setUpZCML()

        import plone.app.customerize

        xmlconfig.file(
            "configure.zcml",
            plone.app.customerize,
            context=self["configurationContext"],
        )
        xmlconfig.file(
            "testing.zcml",
            plone.app.customerize.tests,
            context=self["configurationContext"],
        )
        xmlconfig.file(
            "duplicate_viewlet.zcml",
            plone.app.customerize.tests,
            context=self["configurationContext"],
        )


PLONE_APP_CUSTOMERIZE_FIXTURE = PloneAppCustomerize()
PLONE_APP_CUSTOMERIZE_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(PLONE_APP_CUSTOMERIZE_FIXTURE,),
    name="PloneAppCustomerize:Functional",
)



from zope.interface import Interface


class IMyLayer(Interface):
    """marker interface for a layer for testing purposes"""


class IOtherLayer(Interface):
    """marker interface for a second layer for testing purposes"""



from pathlib import Path
from setuptools import find_packages
from setuptools import setup


version = "2.0.1"

long_description = (
    f"{Path('README.rst').read_text()}\n{Path('CHANGES.rst').read_text()}"
)

setup(
    name="plone.app.customerize",
    version=version,
    description="Integrate five.customerize into Plone.",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    # Get more strings from
    # https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 6.0",
        "Framework :: Plone :: Core",
        "Framework :: Zope :: 5",
        "Intended Audience :: Other Audience",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Internet :: WWW/HTTP :: Site Management",
    ],
    keywords="customerize plone views page templates zmi",
    author="Plone Foundation",
    author_email="plone-developers@lists.sourceforge.net",
    url="https://pypi.org/project/plone.app.customerize/",
    license="GPL version 2",
    packages=find_packages(),
    namespace_packages=["plone", "plone.app"],
    include_package_data=True,
    python_requires=">=3.8",
    extras_require=dict(
        test=[
            "Products.GenericSetup",
            "plone.app.layout",
            "plone.app.testing",
            "plone.testing",
        ]
    ),
    install_requires=[
        "setuptools",
        "five.customerize",
        "plone.browserlayer",
        "plone.portlets",
        "zope.component",
        "zope.interface",
        "zope.publisher",
        "zope.viewlet",
        "Products.CMFCore",
        "Acquisition",
    ],
    platforms="Any",
    zip_safe=False,
)



from plone.app.customerize.tool import ViewTemplateContainer
from Products.CMFCore.utils import ToolInit


def initialize(context):
    """initialize function called when used as a zope2 product"""

    ToolInit(
        "plone.app.customerize",
        tools=(ViewTemplateContainer,),
        icon="tool.gif",
    ).initialize(context)
